@@ -57,8 +57,7 @@ int main(int argc, char *argv[])
 	int ret;
 
 	if (argc < 4 || argc > 5) {
-		fprintf(stderr, "%s <family> <table> <set> [<json>]\n",
-			argv[0]);
+		fprintf(stderr, "%s <family> <table> <set>\n", argv[0]);
 		return EXIT_FAILURE;
 	}
 	t = nftnl_set_alloc();
@@ -80,9 +79,6 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	if (argc == 5 && strcmp(argv[4], "json") == 0 )
-		type = NFTNL_OUTPUT_JSON;
-
 	nlh = nftnl_set_nlmsg_build_hdr(buf, NFT_MSG_GETSETELEM, family,
 					NLM_F_DUMP|NLM_F_ACK, seq);
 	nftnl_set_set(t, NFTNL_SET_NAME, argv[3]);
