@@ -55,8 +55,8 @@ enum {
 	NFTNL_EXPR_NG_MODULUS,
 	NFTNL_EXPR_NG_TYPE,
 	NFTNL_EXPR_NG_OFFSET,
-	NFTNL_EXPR_NG_SET_NAME,
-	NFTNL_EXPR_NG_SET_ID,
+	NFTNL_EXPR_NG_SET_NAME,		/* deprecated */
+	NFTNL_EXPR_NG_SET_ID,		/* deprecated */
 };
 
 enum {
@@ -259,8 +259,8 @@ enum {
 	NFTNL_EXPR_HASH_SEED,
 	NFTNL_EXPR_HASH_OFFSET,
 	NFTNL_EXPR_HASH_TYPE,
-	NFTNL_EXPR_HASH_SET_NAME,
-	NFTNL_EXPR_HASH_SET_ID,
+	NFTNL_EXPR_HASH_SET_NAME,	/* deprecated */
+	NFTNL_EXPR_HASH_SET_ID,		/* deprecated */
 };
 
 enum {
@@ -280,6 +280,7 @@ enum {
 enum {
 	NFTNL_EXPR_OSF_DREG	= NFTNL_EXPR_BASE,
 	NFTNL_EXPR_OSF_TTL,
+	NFTNL_EXPR_OSF_FLAGS,
 };
 
 enum {
@@ -290,6 +291,12 @@ enum {
 	NFTNL_EXPR_XFRM_SPNUM,
 };
 
+enum {
+	NFTNL_EXPR_SYNPROXY_MSS	= NFTNL_EXPR_BASE,
+	NFTNL_EXPR_SYNPROXY_WSCALE,
+	NFTNL_EXPR_SYNPROXY_FLAGS,
+};
+
 #ifdef __cplusplus
 } /* extern "C" */
 #endif
