@@ -5,11 +5,13 @@
 
 struct nftnl_set {
 	struct list_head	head;
+	struct hlist_node	hnode;
 
 	uint32_t		family;
 	uint32_t		set_flags;
 	const char		*table;
 	const char		*name;
+	uint64_t		handle;
 	uint32_t		key_type;
 	uint32_t		key_len;
 	uint32_t		data_type;
