@@ -42,25 +42,25 @@ nftnl_expr_nat_set(struct nftnl_expr *e, uint16_t type,
 
 	switch(type) {
 	case NFTNL_EXPR_NAT_TYPE:
-		nat->type = *((uint32_t *)data);
+		memcpy(&nat->type, data, sizeof(nat->type));
 		break;
 	case NFTNL_EXPR_NAT_FAMILY:
-		nat->family = *((uint32_t *)data);
+		memcpy(&nat->family, data, sizeof(nat->family));
 		break;
 	case NFTNL_EXPR_NAT_REG_ADDR_MIN:
-		nat->sreg_addr_min = *((uint32_t *)data);
+		memcpy(&nat->sreg_addr_min, data, sizeof(nat->sreg_addr_min));
 		break;
 	case NFTNL_EXPR_NAT_REG_ADDR_MAX:
-		nat->sreg_addr_max = *((uint32_t *)data);
+		memcpy(&nat->sreg_addr_max, data, sizeof(nat->sreg_addr_max));
 		break;
 	case NFTNL_EXPR_NAT_REG_PROTO_MIN:
-		nat->sreg_proto_min = *((uint32_t *)data);
+		memcpy(&nat->sreg_proto_min, data, sizeof(nat->sreg_proto_min));
 		break;
 	case NFTNL_EXPR_NAT_REG_PROTO_MAX:
-		nat->sreg_proto_max = *((uint32_t *)data);
+		memcpy(&nat->sreg_proto_max, data, sizeof(nat->sreg_proto_max));
 		break;
 	case NFTNL_EXPR_NAT_FLAGS:
-		nat->flags = *((uint32_t *)data);
+		memcpy(&nat->flags, data, sizeof(nat->flags));
 		break;
 	default:
 		return -1;
@@ -220,115 +220,37 @@ static inline int nftnl_str2nat(const char *nat)
 	}
 }
 
-static int nftnl_expr_nat_json_parse(struct nftnl_expr *e, json_t *root,
-					struct nftnl_parse_err *err)
-{
-#ifdef JSON_PARSING
-	const char *nat_type, *family_str;
-	uint32_t reg, flags;
-	int val32;
-
-	nat_type = nftnl_jansson_parse_str(root, "nat_type", err);
-	if (nat_type == NULL)
-		return -1;
-
-	val32 = nftnl_str2nat(nat_type);
-	if (val32 < 0)
-		return -1;
-
-	nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_TYPE, val32);
-
-	family_str = nftnl_jansson_parse_str(root, "family", err);
-	if (family_str == NULL)
-		return -1;
-
-	val32 = nftnl_str2family(family_str);
-	if (val32 < 0)
-		return -1;
-
-	nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_FAMILY, val32);
-
-	if (nftnl_jansson_parse_reg(root, "sreg_addr_min", NFTNL_TYPE_U32,
-				  &reg, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_REG_ADDR_MIN, reg);
-
-	if (nftnl_jansson_parse_reg(root, "sreg_addr_max", NFTNL_TYPE_U32,
-				  &reg, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_REG_ADDR_MAX, reg);
-
-	if (nftnl_jansson_parse_reg(root, "sreg_proto_min", NFTNL_TYPE_U32,
-				  &reg, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_REG_PROTO_MIN, reg);
-
-	if (nftnl_jansson_parse_reg(root, "sreg_proto_max", NFTNL_TYPE_U32,
-				  &reg, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_REG_PROTO_MAX, reg);
-
-	if (nftnl_jansson_parse_val(root, "flags", NFTNL_TYPE_U32,
-				  &flags, err) == 0)
-		nftnl_expr_set_u32(e, NFTNL_EXPR_NAT_FLAGS, flags);
-
-	return 0;
-#else
-	errno = EOPNOTSUPP;
-	return -1;
-#endif
-}
-
-static int nftnl_expr_nat_export(char *buf, size_t size,
-				 const struct nftnl_expr *e, int type)
-{
-	struct nftnl_expr_nat *nat = nftnl_expr_data(e);
-	NFTNL_BUF_INIT(b, buf, size);
-
-	if (e->flags & (1 << NFTNL_EXPR_NAT_TYPE))
-		nftnl_buf_str(&b, type, nat2str(nat->type), NAT_TYPE);
-	if (e->flags & (1 << NFTNL_EXPR_NAT_FAMILY))
-		nftnl_buf_str(&b, type, nftnl_family2str(nat->family), FAMILY);
-	if (e->flags & (1 << NFTNL_EXPR_NAT_REG_ADDR_MIN))
-		nftnl_buf_u32(&b, type, nat->sreg_addr_min, SREG_ADDR_MIN);
-	if (e->flags & (1 << NFTNL_EXPR_NAT_REG_ADDR_MAX))
-		nftnl_buf_u32(&b, type, nat->sreg_addr_max, SREG_ADDR_MAX);
-	if (e->flags & (1 << NFTNL_EXPR_NAT_REG_PROTO_MIN))
-		nftnl_buf_u32(&b, type, nat->sreg_proto_min, SREG_PROTO_MIN);
-	if (e->flags & (1 << NFTNL_EXPR_NAT_REG_PROTO_MAX))
-		nftnl_buf_u32(&b, type, nat->sreg_proto_max, SREG_PROTO_MAX);
-	if (e->flags & (1 << NFTNL_EXPR_NAT_FLAGS))
-		nftnl_buf_u32(&b, type, nat->flags, FLAGS);
-
-	return nftnl_buf_done(&b);
-}
-
 static int
 nftnl_expr_nat_snprintf_default(char *buf, size_t size,
 				const struct nftnl_expr *e)
 {
 	struct nftnl_expr_nat *nat = nftnl_expr_data(e);
-	int len = size, offset = 0, ret = 0;
+	int remain = size, offset = 0, ret = 0;
 
-	ret = snprintf(buf, len, "%s ", nat2str(nat->type));
-	SNPRINTF_BUFFER_SIZE(ret, size, len, offset);
+	ret = snprintf(buf, remain, "%s ", nat2str(nat->type));
+	SNPRINTF_BUFFER_SIZE(ret, remain, offset);
 
-	ret = snprintf(buf+offset, len, "%s ", nftnl_family2str(nat->family));
-	SNPRINTF_BUFFER_SIZE(ret, size, len, offset);
+	ret = snprintf(buf + offset, remain, "%s ",
+		       nftnl_family2str(nat->family));
+	SNPRINTF_BUFFER_SIZE(ret, remain, offset);
 
 	if (e->flags & (1 << NFTNL_EXPR_NAT_REG_ADDR_MIN)) {
-		ret = snprintf(buf+offset, len,
+		ret = snprintf(buf + offset, remain,
 			       "addr_min reg %u addr_max reg %u ",
 			       nat->sreg_addr_min, nat->sreg_addr_max);
-		SNPRINTF_BUFFER_SIZE(ret, size, len, offset);
+		SNPRINTF_BUFFER_SIZE(ret, remain, offset);
 	}
 
 	if (e->flags & (1 << NFTNL_EXPR_NAT_REG_PROTO_MIN)) {
-		ret = snprintf(buf+offset, len,
+		ret = snprintf(buf + offset, remain,
 			       "proto_min reg %u proto_max reg %u ",
 			       nat->sreg_proto_min, nat->sreg_proto_max);
-		SNPRINTF_BUFFER_SIZE(ret, size, len, offset);
+		SNPRINTF_BUFFER_SIZE(ret, remain, offset);
 	}
 
 	if (e->flags & (1 << NFTNL_EXPR_NAT_FLAGS)) {
-		ret = snprintf(buf+offset, len, "flags %u", nat->flags);
-		SNPRINTF_BUFFER_SIZE(ret, size, len, offset);
+		ret = snprintf(buf + offset, remain, "flags %u", nat->flags);
+		SNPRINTF_BUFFER_SIZE(ret, remain, offset);
 	}
 
 	return offset;
@@ -343,46 +265,19 @@ nftnl_expr_nat_snprintf(char *buf, size_t size, uint32_t type,
 		return nftnl_expr_nat_snprintf_default(buf, size, e);
 	case NFTNL_OUTPUT_XML:
 	case NFTNL_OUTPUT_JSON:
-		return nftnl_expr_nat_export(buf, size, e, type);
 	default:
 		break;
 	}
 	return -1;
 }
 
-static bool nftnl_expr_nat_cmp(const struct nftnl_expr *e1,
-			       const struct nftnl_expr *e2)
-{
-	struct nftnl_expr_nat *n1 = nftnl_expr_data(e1);
-	struct nftnl_expr_nat *n2 = nftnl_expr_data(e2);
-	bool eq = true;
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_REG_ADDR_MIN))
-		eq &= (n1->sreg_addr_min == n2->sreg_addr_min);
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_REG_ADDR_MAX))
-		eq &= (n1->sreg_addr_max == n2->sreg_addr_max);
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_REG_PROTO_MIN))
-		eq &= (n1->sreg_proto_min == n2->sreg_proto_min);
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_REG_PROTO_MAX))
-		eq &= (n1->sreg_proto_max == n2->sreg_proto_max);
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_FAMILY))
-		eq &= (n1->family == n2->family);
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_TYPE))
-		eq &= (n1->type == n2->type);
-	if (e1->flags & (1 << NFTNL_EXPR_NAT_FLAGS))
-		eq &= (n1->flags == n2->flags);
-
-	return eq;
-}
-
 struct expr_ops expr_ops_nat = {
 	.name		= "nat",
 	.alloc_len	= sizeof(struct nftnl_expr_nat),
 	.max_attr	= NFTA_NAT_MAX,
-	.cmp		= nftnl_expr_nat_cmp,
 	.set		= nftnl_expr_nat_set,
 	.get		= nftnl_expr_nat_get,
 	.parse		= nftnl_expr_nat_parse,
 	.build		= nftnl_expr_nat_build,
 	.snprintf	= nftnl_expr_nat_snprintf,
-	.json_parse	= nftnl_expr_nat_json_parse,
 };
