@@ -28,13 +28,13 @@ static int nftnl_obj_quota_set(struct nftnl_obj *e, uint16_t type,
 
 	switch (type) {
 	case NFTNL_OBJ_QUOTA_BYTES:
-		quota->bytes = *((uint64_t *)data);
+		memcpy(&quota->bytes, data, sizeof(quota->bytes));
 		break;
 	case NFTNL_OBJ_QUOTA_CONSUMED:
-		quota->consumed = *((uint64_t *)data);
+		memcpy(&quota->consumed, data, sizeof(quota->consumed));
 		break;
 	case NFTNL_OBJ_QUOTA_FLAGS:
-		quota->flags = *((uint32_t *)data);
+		memcpy(&quota->flags, data, sizeof(quota->flags));
 		break;
 	default:
 		return -1;
@@ -125,47 +125,6 @@ nftnl_obj_quota_parse(struct nftnl_obj *e, struct nlattr *attr)
 	return 0;
 }
 
-static int
-nftnl_obj_quota_json_parse(struct nftnl_obj *e, json_t *root,
-				 struct nftnl_parse_err *err)
-{
-#ifdef JSON_PARSING
-	uint64_t bytes;
-	uint32_t flags;
-
-	if (nftnl_jansson_parse_val(root, "bytes", NFTNL_TYPE_U64, &bytes,
-				  err) == 0)
-		nftnl_obj_set_u64(e, NFTNL_OBJ_QUOTA_BYTES, bytes);
-	if (nftnl_jansson_parse_val(root, "consumed", NFTNL_TYPE_U64, &bytes,
-				    err) == 0)
-		nftnl_obj_set_u64(e, NFTNL_OBJ_QUOTA_CONSUMED, bytes);
-	if (nftnl_jansson_parse_val(root, "flags", NFTNL_TYPE_U32, &flags,
-				  err) == 0)
-		nftnl_obj_set_u32(e, NFTNL_OBJ_QUOTA_FLAGS, flags);
-
-	return 0;
-#else
-	errno = EOPNOTSUPP;
-	return -1;
-#endif
-}
-
-static int nftnl_obj_quota_export(char *buf, size_t size,
-				   const struct nftnl_obj *e, int type)
-{
-	struct nftnl_obj_quota *quota = nftnl_obj_data(e);
-	NFTNL_BUF_INIT(b, buf, size);
-
-	if (e->flags & (1 << NFTNL_OBJ_QUOTA_BYTES))
-		nftnl_buf_u64(&b, type, quota->bytes, BYTES);
-	if (e->flags & (1 << NFTNL_OBJ_QUOTA_CONSUMED))
-		nftnl_buf_u64(&b, type, quota->consumed, CONSUMED);
-	if (e->flags & (1 << NFTNL_OBJ_QUOTA_FLAGS))
-		nftnl_buf_u32(&b, type, quota->flags, FLAGS);
-
-	return nftnl_buf_done(&b);
-}
-
 static int nftnl_obj_quota_snprintf_default(char *buf, size_t len,
 					       const struct nftnl_obj *e)
 {
@@ -187,7 +146,6 @@ static int nftnl_obj_quota_snprintf(char *buf, size_t len, uint32_t type,
 		return nftnl_obj_quota_snprintf_default(buf, len, e);
 	case NFTNL_OUTPUT_XML:
 	case NFTNL_OUTPUT_JSON:
-		return nftnl_obj_quota_export(buf, len, e, type);
 	default:
 		break;
 	}
@@ -204,5 +162,4 @@ struct obj_ops obj_ops_quota = {
 	.parse		= nftnl_obj_quota_parse,
 	.build		= nftnl_obj_quota_build,
 	.snprintf	= nftnl_obj_quota_snprintf,
-	.json_parse	= nftnl_obj_quota_json_parse,
 };
